@@ -99,10 +99,14 @@ static void print_table(char *table, int id)
 
     if (id == YUBIKEY || id == OATH) {
         query = calloc(1, QUERY_SIZE);
-        sprintf(query, "SELECT nickname,publicname,active FROM %s", table);
+        snprintf(query, QUERY_SIZE,
+                 "SELECT nickname,publicname,active FROM %s",
+                 table);
     } else if (id == API) {
         query = calloc(1, QUERY_SIZE);
-        sprintf(query, "SELECT nickname,id FROM %s", table);
+        snprintf(query, QUERY_SIZE,
+                 "SELECT nickname,id FROM %s",
+                 table);
     }
     retval = sqlite3_open(sqlite3_dbpath, &handle);
 
@@ -170,7 +174,11 @@ static int finduser(char *table, char *user, sqlite3 *handle)
     sqlite3_stmt *stmt;
 
     query = calloc(1, QUERY_SIZE);
-    sprintf(query, "SELECT * FROM %s WHERE nickname='%s'", table, user);
+    snprintf(query,
+             QUERY_SIZE,
+             "SELECT * FROM %s WHERE nickname='%s'",
+             table,
+             user);
 
     retval = sqlite3_prepare_v2(handle, query, -1, &stmt, 0);
 
@@ -217,9 +225,11 @@ static void userenable(char *table, char *user)
     }
 
     query = calloc(1, QUERY_SIZE);
-    sprintf(query, "SELECT * FROM %s WHERE nickname = '%s' AND active = '1'",
-            table,
-            user);
+    snprintf(query,
+             QUERY_SIZE,
+             "SELECT * FROM %s WHERE nickname = '%s' AND active = '1'",
+             table,
+             user);
 
     retval = sqlite3_prepare_v2(handle, query, -1, &stmt, 0);
 
@@ -235,8 +245,12 @@ static void userenable(char *table, char *user)
         break;
     case SQLITE_DONE:
         fprintf(stdout, "Trying to enable user '%s'\n", user);
-        sprintf(query, "UPDATE %s SET active = '1' WHERE "
-                       "nickname = '%s'", table, user);
+        snprintf(query,
+                 QUERY_SIZE,
+                 "UPDATE %s SET active = '1' WHERE "
+                 "nickname = '%s'",
+                 table,
+                 user);
         retval = sqlite3_exec(handle, query, 0, 0, 0);
         if (retval) {
             fprintf(stderr, "Updating DB data failed\n");
@@ -276,9 +290,11 @@ static void userdisable(char *table, char *user)
 
     query = calloc(1, QUERY_SIZE);
 
-    sprintf(query, "SELECT * FROM %s WHERE nickname = '%s' AND active = '0'",
-            table,
-            user);
+    snprintf(query,
+             QUERY_SIZE,
+             "SELECT * FROM %s WHERE nickname = '%s' AND active = '0'",
+             table,
+             user);
 
     retval = sqlite3_prepare_v2(handle, query, -1, &stmt, 0);
 
@@ -294,8 +310,12 @@ static void userdisable(char *table, char *user)
         break;
     case SQLITE_DONE:
         fprintf(stdout, "Trying to disable user '%s'\n", user);
-        sprintf(query, "UPDATE %s SET active = '0' WHERE "
-                       "nickname = '%s'", table, user);
+        snprintf(query,
+                 QUERY_SIZE,
+                 "UPDATE %s SET active = '0' WHERE "
+                 "nickname = '%s'",
+                 table,
+                 user);
         retval = sqlite3_exec(handle, query, 0, 0, 0);
         if (retval) {
             fprintf(stderr, "Failed to disable user\n");
@@ -335,7 +355,11 @@ static void userdelete(char *table, char *user)
 
     query = calloc(1, QUERY_SIZE);
 
-    sprintf(query, "DELETE FROM %s WHERE nickname = '%s'", table, user);
+    snprintf(query,
+             QUERY_SIZE,
+             "DELETE FROM %s WHERE nickname = '%s'",
+             table,
+             user);
     retval = sqlite3_exec(handle, query, 0, 0, 0);
 
     if (retval) {
@@ -358,7 +382,10 @@ static int find_nextid(char *table, sqlite3 *handle)
     sqlite3_stmt *stmt;
 
     query = calloc(1, QUERY_SIZE);
-    sprintf(query, "SELECT id FROM %s ORDER BY id DESC LIMIT 1", table);
+    snprintf(query,
+             QUERY_SIZE,
+             "SELECT id FROM %s ORDER BY id DESC LIMIT 1",
+             table);
 
     retval = sqlite3_prepare_v2(handle, query, -1, &stmt, 0);
 
@@ -394,8 +421,12 @@ static int finduser_public(char *table, char *user, char *pname,
     sqlite3_stmt *stmt;
 
     query = calloc(1, QUERY_SIZE);
-    sprintf(query,"SELECT * FROM %s WHERE nickname='%s' OR publicname='%s'",
-            table, user, pname);
+    snprintf(query,
+             QUERY_SIZE,
+             "SELECT * FROM %s WHERE nickname='%s' OR publicname='%s'",
+             table,
+             user,
+             pname);
 
     retval = sqlite3_prepare_v2(handle, query, -1, &stmt, 0);
 
@@ -467,17 +498,19 @@ static void useradd_yubikey(char *table, char *user)
     cdatetime = calloc(1, 25);
     cdatetime_tmp = calloc(1, 20);
     strftime(cdatetime_tmp, 20, "%Y-%m-%dT%H:%M:%S", tmp);
-    sprintf(cdatetime, "%s.%.3dZ", cdatetime_tmp, tp.millitm);
+    snprintf(cdatetime, 25, "%s.%.3dZ", cdatetime_tmp, tp.millitm);
 
     query = calloc(1, QUERY_SIZE * 2);
-    sprintf(query, "INSERT INTO %s "
-                   "VALUES('%s','%s','%s','%s','%s',1,1,1)",
-                   table,
-                   user,
-                   ext_db ? Argv[6]: Argv[4],
-                   cdatetime,
-                   ext_db ? Argv[7]: Argv[5],
-                   ext_db ? Argv[8]: Argv[6]);
+    snprintf(query,
+             QUERY_SIZE * 2,
+             "INSERT INTO %s "
+             "VALUES('%s','%s','%s','%s','%s',1,1,1)",
+             table,
+             user,
+             ext_db ? Argv[6]: Argv[4],
+             cdatetime,
+             ext_db ? Argv[7]: Argv[5],
+             ext_db ? Argv[8]: Argv[6]);
     free(cdatetime);
     free(cdatetime_tmp);
 
@@ -543,16 +576,18 @@ static void useradd_oath(char *table, char *user)
     cdatetime = calloc(1, 25 + 1);
     cdatetime_tmp = calloc(1, 20 + 1);
     strftime(cdatetime_tmp, 20, "%Y-%m-%dT%H:%M:%S", tmp);
-    sprintf(cdatetime, "%s.%.3dZ", cdatetime_tmp, tp.millitm);
+    snprintf(cdatetime, 25, "%s.%.3dZ", cdatetime_tmp, tp.millitm);
 
     query = calloc(1, QUERY_SIZE * 2);
-    sprintf(query, "INSERT INTO %s "
-                   "VALUES('%s','%s','%s','%s',1,1)",
-                   table,
-                   user,
-                   ext_db ? Argv[6]: Argv[4],
-                   cdatetime,
-                   ext_db ? Argv[7]: Argv[5]);
+    snprintf(query,
+            QUERY_SIZE * 2,
+            "INSERT INTO %s "
+            "VALUES('%s','%s','%s','%s',1,1)",
+            table,
+            user,
+            ext_db ? Argv[6]: Argv[4],
+            cdatetime,
+            ext_db ? Argv[7]: Argv[5]);
     free(cdatetime);
     free(cdatetime_tmp);
 
@@ -610,10 +645,12 @@ static void useradd_api(char *table, char *user)
     }
 
     query = calloc(1, QUERY_SIZE);
-    sprintf(query, "INSERT INTO apikeys VALUES ('%s','%s','%d')",
-                   user,
-                   ext_db ? Argv[6] : Argv[4],
-                   nextid);
+    snprintf(query,
+             QUERY_SIZE,
+             "INSERT INTO apikeys VALUES ('%s','%s','%d')",
+             user,
+             ext_db ? Argv[6] : Argv[4],
+             nextid);
 
     retval = sqlite3_exec(handle, query, 0, 0, 0);
 
